@@ -148,7 +148,7 @@ r_session <- R6::R6Class(
     #'   * `301`: (`MSG`) A message from the subprocess. The message is a
     #'      condition object with class `callr_message`. (It typically has
     #'      other classes, e.g. `cli_message` for output from the cli
-    #'      package.
+    #'      package.)
     #'   * `500`: (`EXITED`) The R session finished cleanly. This means
     #'      that the evaluated expression quit R.
     #'   * `501`: (`CRASHED`) The R session crashed or was killed.
@@ -258,6 +258,7 @@ rs_init <- function(self, private, super, options, wait, wait_timeout) {
 
   private$options <- options
 
+  prepare_client_files()
   with_envvar(
     options$env,
     do.call(super$initialize, c(list(options$bin, options$real_cmdargs,
@@ -463,6 +464,8 @@ rs_call <- function(self, private, func, args, package) {
   private$report_back(200, report_str)
 
   private$state <- "busy"
+
+
 }
 
 rs_run_with_output <- function(self, private, func, args, package) {
@@ -536,7 +539,9 @@ rs_poll_process <- function(self, private, timeout) {
 
 rs_traceback <- function(self, private) {
   ## TODO: get rid of magic number 12
-  traceback(utils::head(self$run(function() traceback()), -12))
+  traceback(utils::head(self$run(function() {
+    traceback(as.environment("tools:callr")$`__callr_data__`$.Traceback, 10)
+  }), -12))
 }
 
 rs_debug <- function(self, private) {
@@ -848,8 +853,36 @@ rs__handle_condition <- function(cond) {
 #' Create options for an [r_session] object
 #'
 #' @param ... Options to override, named arguments.
+#' @return Named list of options.
+#'
+#' The current options are:
+#' * `libpath`: Library path for the subprocess. By default the same as the
+#'   _current_ library path. I.e. _not_ necessarily the library path of
+#'   a fresh R session.)
+#' * `repos`: `repos` option for the subprocess. By default the current
+#'   value of the main process.
+#' * `stdout`: Standard output of the sub-process. This can be `NULL` or
+#'   a pipe: `"|"`. If it is a pipe then the output of the subprocess is
+#'   not included in the responses, but you need to poll and read it
+#'   manually. This is for exports.
+#' * `stderr`: Similar to `stdout`, but for the standard error.
+#' * `error`: See 'Error handling' in [r()].
+#' * `cmdargs`: See the same argument of [r()]. (Its default might be
+#'   different, though.)
+#' * `system_profile`: See the same argument of [r()].
+#' * `user_profile`: See the same argument of [r()].
+#' * `env`: See the same argument of [r()].
+#' * `load_hook`: `NULL`, or code (quoted) to run in the sub-process
+#'   at start up. (I.e. not for every single `run()` call.)
+#' * `extra`: List of extra arguments to pass to [processx::process].
+#'
+#' Call `r_session_options()` to see the default values.
+#' `r_session_options()` might contain undocumented entries, you cannot
+#' change these.
 #'
 #' @export
+#' @examples
+#' r_session_options()
 
 r_session_options <- function(...) {
   update_options(r_session_options_default(), ...)
@@ -875,7 +908,8 @@ r_session_options_default <- function() {
     env = c(TERM = "dumb"),
     supervise = FALSE,
     load_hook = NULL,
-    extra = list()
+    extra = list(),
+    arch = "same"
   )
 }
 
