@@ -270,9 +270,7 @@ test_that("traceback", {
 
   expect_error(rs$run(do), "oops")
   expect_output(tb <- rs$traceback(), "1: \"?f()\"?")
-  if (getRversion() >= "3.3.0" && getRversion() <= "4.0.0") {
-    expect_match(c(tb[[4]]), "f()", fixed = TRUE)
-  }
+  expect_match(c(tb[[3]]), "f()", fixed = TRUE)
 })
 
 test_that("error in the load hook", {
@@ -287,6 +285,20 @@ test_that("error in the load hook", {
 
   processx::poll(list(rs2$get_poll_connection()), 3000)
   msg <- rs2$read()
-  expect_equal(msg$code, 501L)
+  expect_true(msg$code %in% c(501L, 502L))
   expect_match(msg$stderr, "oops")
 })
+
+test_that("fds are not leaked", {
+  rs <- r_session$new()
+  on.exit(rs$kill(), add = TRUE)
+
+  old <- rs$run(function() ps::ps_num_fds())
+  for (i in 1:10) {
+    rs$run(function() 1 + 1)
+  }
+  new <- rs$run(function() ps::ps_num_fds())
+
+  # Allow 2 new fds, just in case
+  expect_true(new - old <= 2)
+})
